### Hexlet tests and linter status:
[![Actions Status](https://github.com/Pengue/python-project-49/workflows/hexlet-check/badge.svg)](https://github.com/Pengue/python-project-49/actions)
[![Maintainability](https://api.codeclimate.com/v1/badges/26cbe53cff2aa1026fef/maintainability)](https://codeclimate.com/github/Pengue/python-project-49)

# Brain Games. Level 1 project on [Hexlet](https://ru.hexlet.io/professions/python/projects/49), program: Python developer.

Installation:

`pip install -i https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple/ pengue-brain-games`

## Installing package and playing in brain-even
<a href="https://asciinema.org/a/560367" target="_blank"><img src="https://asciinema.org/a/560367.svg" /></a>

## Playing in brain-calc
<a href="https://asciinema.org/a/560369" target="_blank"><img src="https://asciinema.org/a/560369.svg" /></a>

## Playing in brain-gcd
<a href="https://asciinema.org/a/560376" target="_blank"><img src="https://asciinema.org/a/560376.svg" /></a>

## Playing in brain-progression
<a href="https://asciinema.org/a/560350" target="_blank"><img src="https://asciinema.org/a/560350.svg" /></a>

## Playing in brain-prime
<a href="https://asciinema.org/a/560358" target="_blank"><img src="https://asciinema.org/a/560358.svg" /></a>